@@ -8,10 +8,20 @@ def checkbanstatus(instance, username):
         The name of your PRAW instance
     username : str
         The name of the Redditor in question
+
+    Returns
+    -------
+    sub_list
+        A list of subs user is banned from
     """
+    sub_list = []
+
     for subreddit in instance.redditor(str(instance.user.me())).moderated():
         try:
             if any(instance.subreddit(subreddit.display_name).banned(redditor=username)):
-                print(subreddit.display_name)
+                #print(subreddit.display_name)
+                sub_list.append(subreddit.display_name)
         except:
-            continue
\ No newline at end of file
+            continue
+
+    return sub_list
\ No newline at end of file
