@@ -9,6 +9,10 @@ def searchmessageinboxkeyword(instance, keyword):
     keyword : str
         The name of the word you're looking for in inbox
     """
+    messages = []
     for message in instance.inbox.all(limit = None):
         if keyword in str(message.body) or keyword in str(message.subject):
-            print(message.body)
\ No newline at end of file
+            #print(message.body)
+            messages.append(message.body)
+    
+    return messages;
\ No newline at end of file
